﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace xamTree_NodeEvents
{
    public class SampleStates : INotifyPropertyChanged
    {
        /// <summary>
        /// Name of the state.
        /// </summary>
        private string m_stateName;

        /// <summary>
        /// Name of the state.
        /// </summary>
        public string StateName
        {
            get { return this.m_stateName; }
            set { this.m_stateName = value; PropertyChanged(this, new PropertyChangedEventArgs("StateName")); }
        }

        /// <summary>
        /// A collection of cities inside this state.
        /// </summary>
        public ObservableCollection<SampleCities> Cities { get; private set; }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="name">The name of the state.</param>
        public SampleStates(string name)
        {
            this.m_stateName = name;

            this.Cities = new ObservableCollection<SampleCities>();
            switch (name)
            {
                case "New York":
                    this.Cities.Add(new SampleCities("New York City", 154235));
                    this.Cities.Add(new SampleCities("Rochester", 63424));
                    break;

                case "Florida":
                    this.Cities.Add(new SampleCities("Miami", 843234));
                    this.Cities.Add(new SampleCities("Orlando", 94234));
                    break;

                case "Texas":
                    this.Cities.Add(new SampleCities("Houston", 1423765));
                    break;

                case "California":
                    this.Cities.Add(new SampleCities("San Francisco", 2357909));
                    break;
            }
        }

        /// <summary>
        /// Override so we show the state's name.
        /// </summary>
        /// <returns></returns>
        public override string ToString()
        {
            return this.StateName;
        }
    }
}
